[![CI Testing](https://github.com/chembl/libRDChEBI/workflows/CI/badge.svg)](https://github.com/chembl/libRDChEBI/actions?query=workflow%3ACI+branch%3Amain)
[![Latest Version](https://img.shields.io/pypi/v/libRDChEBI.svg)](https://pypi.python.org/pypi/libRDChEBI/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/libRDChEBI.svg)](https://pypi.python.org/pypi/libRDChEBI/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

# libRDChEBI

RDKit-based library implementing chemistry-related functions used in the development of the new [ChEBI](https://wwwdev.ebi.ac.uk/chebi/alpha/) platform, providing functionality similar to the existing ChEBI system.
